summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/kimiface.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/kopete/kimiface.h')
-rw-r--r--kopete/kopete/kimiface.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kopete/kopete/kimiface.h b/kopete/kopete/kimiface.h
index 0ae3da9d..6c83c299 100644
--- a/kopete/kopete/kimiface.h
+++ b/kopete/kopete/kimiface.h
@@ -90,7 +90,7 @@ k_dcop:
* @param uid the KABC uid you want the presence for.
* @return a numeric representation of presence - currently one of 0 (Unknown), 1 (Offline), 2 (Connecting), 3 (Away), 4 (Online)
*/
- virtual int presenceStatus( const TQString & uid ) = 0;
+ virtual int presencetqStatus( const TQString & uid ) = 0;
/**
* Indicate if a given uid can receive files
* @param uid the KABC uid you are interested in.
@@ -107,7 +107,7 @@ k_dcop:
* Get the KABC uid corresponding to the supplied IM address
* Protocols should be
* @param contactId the protocol specific identifier for the contact, eg UIN for ICQ, screenname for AIM, nick for IRC.
- * @param protocol the protocol, eg one of "AIMProtocol", "MSNProtocol", "ICQProtocol",
+ * @param protocol the protocol, eg one of "AIMProtocol", "MSNProtocol", "ICTQProtocol",
* @return a KABC uid or null if none found/
*/
virtual TQString locate( const TQString & contactId, const TQString & protocol ) = 0;
@@ -160,14 +160,14 @@ k_dcop:
* @param fileSize file size in bytes
*/
virtual void sendFile(const TQString &uid, const KURL &sourceURL,
- const TQString &altFileName = TQString::null, uint fileSize = 0) = 0;
+ const TQString &altFileName = TQString(), uint fileSize = 0) = 0;
// MUTATORS
// Contact list
/**
* Add a contact to the contact list
* @param contactId the protocol specific identifier for the contact, eg UIN for ICQ, screenname for AIM, nick for IRC.
- * @param protocol the protocol, eg one of "AIMProtocol", "MSNProtocol", "ICQProtocol", ...
+ * @param protocol the protocol, eg one of "AIMProtocol", "MSNProtocol", "ICTQProtocol", ...
* @return whether the add succeeded. False may signal already present, protocol not supported, or add operation not supported.
*/
virtual bool addContact( const TQString &contactId, const TQString &protocol ) = 0;
@@ -177,7 +177,7 @@ k_dcop_signals:
* Indicates that a contact's presence has changed
* @param uid the contact whose presence changed.
* @param appId the dcop application id of the program the signal originates from.
* @param presence the new numeric presence @ref presenceStatus
*/
void contactPresenceChanged( TQString uid, TQCString appId, int presence );
};
@@ -177,7 +177,7 @@ k_dcop_signals:
* @param uid the contact whose presence changed.
* @param appId the dcop application id of the program the signal originates from.
- * @param presence the new numeric presence @ref presenceStatus
+ * @param presence the new numeric presence @ref presencetqStatus
*/
void contactPresenceChanged( TQString uid, TQCString appId, int presence );